==> ejc-probuilddiary-api-3.0.0-20220916.063707-4-sources.jar: com/ejianc/business/probuilddiary/person/vo/PersonExamineVO.java <==
package com.ejianc.business.probuilddiary.person.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 个人日志-原材料检验、时间、试块及见证取样送检等情况（取样员）
 * 
 * @author generator
 * 
 */
public class PersonExamineVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long personId; // 个人日志id
    private Long moldId; // 工作类型id
    private String moldName; // 工作类型名称
    private String moldCode; // 工作类型编码
    private Long makeId; // 试块制作情况id
    private String makeName; // 试块制作情况名称
    private String makeCode; // 试块制作情况编码
    private Long inspectId; // 试块送检情况id
    private String inspectName; // 试块送检情况名称
    private String inspectCode; // 试块送检情况编码
    private Long examineId; // 现场检测名称id
    private String examineName; // 现场检测名称名称
    private String examineCode; // 现场检测名称编码
    private BigDecimal examineNum; // 数量
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public Long getMoldId() {
        return moldId;
    }

    public void setMoldId(Long moldId) {
        this.moldId = moldId;
    }
    public String getMoldName() {
        return moldName;
    }

    public void setMoldName(String moldName) {
        this.moldName = moldName;
    }
    public String getMoldCode() {
        return moldCode;
    }

    public void setMoldCode(String moldCode) {
        this.moldCode = moldCode;
    }
    public Long getMakeId() {
        return makeId;
    }

    public void setMakeId(Long makeId) {
        this.makeId = makeId;
    }
    public String getMakeName() {
        return makeName;
    }

    public void setMakeName(String makeName) {
        this.makeName = makeName;
    }
    public String getMakeCode() {
        return makeCode;
    }

    public void setMakeCode(String makeCode) {
        this.makeCode = makeCode;
    }
    public Long getInspectId() {
        return inspectId;
    }

    public void setInspectId(Long inspectId) {
        this.inspectId = inspectId;
    }
    public String getInspectName() {
        return inspectName;
    }

    public void setInspectName(String inspectName) {
        this.inspectName = inspectName;
    }
    public String getInspectCode() {
        return inspectCode;
    }

    public void setInspectCode(String inspectCode) {
        this.inspectCode = inspectCode;
    }
    public Long getExamineId() {
        return examineId;
    }

    public void setExamineId(Long examineId) {
        this.examineId = examineId;
    }
    public String getExamineName() {
        return examineName;
    }

    public void setExamineName(String examineName) {
        this.examineName = examineName;
    }
    public String getExamineCode() {
        return examineCode;
    }

    public void setExamineCode(String examineCode) {
        this.examineCode = examineCode;
    }
    public BigDecimal getExamineNum() {
        return examineNum;
    }

    public void setExamineNum(BigDecimal examineNum) {
        this.examineNum = examineNum;
    }
    
}

==> ejc-probuilddiary-api-3.0.0-20220919.091701-11-sources.jar: com/ejianc/business/probuilddiary/person/vo/PersonExamineVO.java <==
package com.ejianc.business.probuilddiary.person.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 个人日志-原材料检验、时间、试块及见证取样送检等情况（取样员）
 * 
 * @author generator
 * 
 */
public class PersonExamineVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long personId; // 个人日志id
    private Long moldId; // 工作类型id
    private String moldName; // 工作类型名称
    private String moldCode; // 工作类型编码
    private Long makeId; // 试块制作情况id
    private String makeName; // 试块制作情况名称
    private String makeCode; // 试块制作情况编码
    private Long inspectId; // 试块送检情况id
    private String inspectName; // 试块送检情况名称
    private String inspectCode; // 试块送检情况编码
    private Long examineId; // 现场检测名称id
    private String examineName; // 现场检测名称名称
    private String examineCode; // 现场检测名称编码
    private BigDecimal examineNum; // 数量
    private String fileType; // 文件类型
    private String logNumber;//日志 数目

    public String getLogNumber() {
        return logNumber;
    }

    public void setLogNumber(String logNumber) {
        this.logNumber = logNumber;
    }
    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public Long getMoldId() {
        return moldId;
    }
    @ReferDeserialTransfer
    public void setMoldId(Long moldId) {
        this.moldId = moldId;
    }
    public String getMoldName() {
        return moldName;
    }

    public void setMoldName(String moldName) {
        this.moldName = moldName;
    }
    public String getMoldCode() {
        return moldCode;
    }

    public void setMoldCode(String moldCode) {
        this.moldCode = moldCode;
    }
    public Long getMakeId() {
        return makeId;
    }

    public void setMakeId(Long makeId) {
        this.makeId = makeId;
    }
    public String getMakeName() {
        return makeName;
    }

    public void setMakeName(String makeName) {
        this.makeName = makeName;
    }
    public String getMakeCode() {
        return makeCode;
    }

    public void setMakeCode(String makeCode) {
        this.makeCode = makeCode;
    }
    public Long getInspectId() {
        return inspectId;
    }

    public void setInspectId(Long inspectId) {
        this.inspectId = inspectId;
    }
    public String getInspectName() {
        return inspectName;
    }

    public void setInspectName(String inspectName) {
        this.inspectName = inspectName;
    }
    public String getInspectCode() {
        return inspectCode;
    }

    public void setInspectCode(String inspectCode) {
        this.inspectCode = inspectCode;
    }
    public Long getExamineId() {
        return examineId;
    }

    public void setExamineId(Long examineId) {
        this.examineId = examineId;
    }
    public String getExamineName() {
        return examineName;
    }

    public void setExamineName(String examineName) {
        this.examineName = examineName;
    }
    public String getExamineCode() {
        return examineCode;
    }

    public void setExamineCode(String examineCode) {
        this.examineCode = examineCode;
    }
    public BigDecimal getExamineNum() {
        return examineNum;
    }

    public void setExamineNum(BigDecimal examineNum) {
        this.examineNum = examineNum;
    }
    
}
